package org.w3c.rdfpic.core;
import org.w3c.rdf.model.*;
import org.w3c.rdf.implementation.model.*;
import org.w3c.rdf.syntax.*;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;
import java.io.StringReader;
import java.io.StringWriter;
import java.io.IOException;

/**
 * Rdf2ImgMeta provides two handy models that connect the SiRPAC package to
 * the ImgMetaHandler, essentially setting up Reader's and Writer's handily.
 */

public class Rdf2ImgMeta
{

    /**
     * Saves a Model to the given ImgMetaHandler with help from the RDFSerializer.
     */
    static void save(Model model,ImgMetaHandler handler,RDFSerializer serializer) throws IOException,ModelException,SerializationException
    {
	StringWriter sw = new StringWriter();
	serializer.serialize(model,sw);
	handler.write(sw.toString());
    }
    /**
     * Loads a Model from the given ImgMetaHandler with help from the RDFParser.
     */
    static Model load(ImgMetaHandler handler,RDFParser parser) throws IOException,SAXException
    {
	Rdf2MetaLoader l = new Rdf2MetaLoader(new ModelImpl());
	parser.parse(new InputSource(new StringReader(handler.read())),l);
	return l.model;
    }
}

/**
 * Provides a "sink" for all the rdf-data found when parsing an puts it into a model.
 */

class Rdf2MetaLoader implements RDFConsumer 
{
    Model model;
    /**
     * Construct and add all rdf statements to the given model.
     */
    Rdf2MetaLoader(Model model)
    {
	this.model=model;
    }
    public void addStatement(Statement s)
    {
	try {
	    model.add(s);
	} catch(ModelException err) {
	    err.printStackTrace();
	    System.err.print("(Exception caught)");
	}
    }
    public void endModel() {}
    public void startModel() {}
    public NodeFactory getNodeFactory()
    {
	try {
	    return model.getNodeFactory();
	} catch(ModelException err) {
	    err.printStackTrace();
	    System.err.print("(Exception caught)");
	}
	return null;
    }
}

