package org.w3c.rdfpic.ui;
import javax.swing.JComboBox;
/**
 * A <code>CboxMaker</code> provides support for builtin functionality, e.g. the DC:Subject field.
 * Register a <code>CboxMaker</code> in a <code>SchemaTabbedPane</code> with <code>SchemaTabbedPane.addBuiltin(String predName,CboxMaker cboxMaker)</code>.
 * When a SchemaTabbedPane encounters a predicate starting with "_" in a schema with the builtin bit on, it strips the underscore
 * and passes on the remainder of the predicate name to the CboxMaker registered with that predicate.
 *
 * The <code>JComboBox</code> returned by <code>newCbox</code> must support the following:
 * <ul><li><code>getSelectedItem</code> which must return a <code>String</code>.
 *     <li><code>setSelectedItem</code> which must "reset" the state when passed <code>null</code>, and be able to interpret the output produced by
 *         <code>getSelectedItem</code>.
 *     <li><code>setEnabled</code>.  No other functions are used by CboxMaker.
 * </ul>
 */
public interface CboxMaker {
    /**
     * Called by a SchemaTabbedPane upon encountering a field starting with an underscore in a schema with the builtin bit enabled.
     */
    public JComboBox newCbox(String predName);
    /**
     * Called by a SchemaTabbedPane whenever a new image file is (successfully) loaded.
     * It is not necessary to reset any <code>JComboBoxes</code> made, as <code>setSelectedItem(null)</code> will be called on them
     * if necessary.
     */
    public void newFileLoaded();
}
